@@ -8,7 +8,7 @@ use Carp qw(carp);
 
 use base 'Bio::Root::Root';
 
-use version; our $VERSION = qv('0.5.0');
+use version; our $VERSION = qv('0.6.0');
 
 use Class::MethodMaker [
    new    => 'new2',
@@ -65,50 +65,7 @@ sub alignment_string {
    return $result;
 }
 
-sub alignment_to_csv {
 
-   # gets an alignment and returns and string for a CSV-file
-   my $self = shift;
-
-   my $aln = $self->alignment;
-   unless (defined ($aln)) {
-      $self->warn("No alignment calculated.");
-      return "";
-   }   
-   return $self->get_gene_id() . ','
-     . $_->_commafy_string( $aln->get_seq_by_pos(1)->seq ) . ","
-     . $self->sequence->id . "\n,"
-     . $self->_commafy_string( $aln->match_line )
-     . ",\nQuery" . ","
-     . $_->_commafy_string( $aln->get_seq_by_pos(2)->seq )
-     . ",dG = "
-     . $self->dG . "\n";
-}
-
-sub get_gene_id {
-   my $self = shift;
-   my $desc = $self->sequence->id;
-   $desc =~ s/^(.*?)( |\|)//;
-   return $1;
-}
-
-sub _commafy_string {
-
-   # param: string
-   # output: s,t,r,i,n,g
-   my ( $self, $s ) = @_;
-   if (!defined $s) {
-      $self->throw(-class => 'Bio::Root::BadParameter',
-                   -text  => 'Missing Parameter',);
-   }
-   
-   my $result = "";
-   for ( my $i = 0 ; $i != length($s) ; ++$i ) {
-      $result .= substr( $s, $i, 1 ) . ',';
-   }
-   chop($result);
-   return $result;
-}
 1;# Magic true value required at end of module
 __END__
 
@@ -139,7 +96,8 @@ Bio::Grep::Container::SearchResult - Data structure for a back-end search hit
 
 =head1 DESCRIPTION
 
-B<Bio::Grep::Container::SearchResult> is the data structure for one hit in the database.
+B<Bio::Grep::Container::SearchResult> is the data structure for one hit in the
+database.
 
 =head1 METHODS
 
@@ -147,8 +105,8 @@ B<Bio::Grep::Container::SearchResult> is the data structure for one hit in the d
 
 =item C<new(sequence, begin, end, alignment, sequence_id, remark)>;
 
-This function constructs a SearchResult object. 
-
+This function constructs a Bio::Grep::Container::SearchResult object. 
+Only called by the back-end parser. 
 
 =item C<sequence()>
 
@@ -165,38 +123,34 @@ Get the query as L<Bio::Seq> object. Useful for multiple queries.
 
 =item C<alignment()>
 
-Get/set the alignment of the match. See L<Bio::SimpleAlign> for details. There are powerful
-modules for converting this module in many formats. See L<Bio::AlignIO> for details.
-
-=item C<get_gene_id()>
-
-This function tries to guess gene name out of C<sequence-E<gt>name>.
-
+Get/set the alignment of the match. See L<Bio::SimpleAlign> for details. There
+are powerful modules for converting this module in many formats. See 
+L<Bio::AlignIO> for details.
 
 =item C<sequence_id()>
 
 Getter/Setter for sequence ID in database. This is an internal ID of the
-back-end, not any ID of some annotation in the sequence name. Use
-get_gene_id() to guess this ID. The internal ID can be used in the
-back-end function get_sequences (L<Bio::Grep::Backends::BackendI>).
+back-end, not any ID of some annotation in the sequence name. The internal ID 
+can be used in the back-end function get_sequences 
+(L<Bio::Grep::Backends::BackendI>).
 
 =item C<begin()>
 
-Get/set the position of the beginning of the subject in the sequence. This allows 
-retrieving upstream regions from the back-end. First position is 0.
+Get/set the position of the beginning of the subject in the sequence. This 
+allows retrieving upstream regions from the back-end. First position is 0.
 
     my $seq = $res->sequence->seq;
     my $upstream   = substr $seq, 0, $res->begin;
     my $subject    = substr $seq, $res->begin, $res->end - $res->begin;
     my $downstream = substr $seq, $res->end;
 
-Note that C<$res-E<gt>begin> differs from C<$sbe-E<gt>settings-E<gt>upstream> if the
-available upstream region is smaller than requested!
+Note that C<$res-E<gt>begin> differs from C<$sbe-E<gt>settings-E<gt>upstream> 
+if the available upstream region is smaller than requested!
 
 =item C<end()>
 
-Get/set the position of the end of the subject in the sequence. This allows retrieving
-downstream regions from the back-end. See C<begin()>.
+Get/set the position of the end of the subject in the sequence. This allows
+retrieving downstream regions from the back-end. See C<begin()>.
 
 =item C<dG()>
 
@@ -234,11 +188,6 @@ Format without many blank lines and CLUSTAL header. In some back-ends like
 Agrep, this function will return an empty string if no_alignments is true
 in the back-end search settings (L<Bio::Grep::Container::SearchSettings>).
 
-=item C<alignment_to_csv()>
-
-This function generates a string for a CSV file, where every base of the stored alignment gets its own column. Additional infos
-like description and dG are displayed, too.
-
 =back
 
 =head1 SEE ALSO
@@ -248,7 +197,6 @@ L<Bio::LocatableSeq>
 L<Bio::AlignIO> 
 L<Bio::Seq>
 L<Bio::SeqIO>
-L<Weigel::RNA::HybridizationI>
 L<Bio::Grep::Backends::BackendI>
 
 =head1 AUTHOR
